import jQuery from "jquery";

export default class ToolMenu {
    constructor() {
        this.warnings = false;
        this.values = {};
        this.initialShow = true;
    }

    loadTool(tool) {
        this.tool = tool;
        this.menuId = this.tool.getKey() + "-menu";
    }

    show() {
        this.onMenuShow(this.initialShow);
        this.initialShow = false;
        this.getMenu().removeClass("hidden");
    }

    hide() {
        this.getMenu().addClass("hidden");
        this.onMenuHide();
    }

    onMenuShow(initial) {
        if (this.warnings) {
            console.warn('Method "onMenuShow" not implemented.');
        }
    }

    onMenuHide() {
        if (this.warnings) {
            console.warn('Method "onMenuHide" not implemented.');
        }
    }

    beforeGet(key) {
        if (this.warnings) {
            console.warn('Method "beforeGet" not implemented.');
        }
    }

    afterSet(key, value) {
        if (this.warnings) {
            console.warn('Method "afterSet" not implemented.');
        }
    }

    notifyTool(key, value) {
        this.values[key] = value;
        this.tool.onMenuChange(key, value);
    }

    value(key, newValue) {
        // If key not defined
        // (be it by giving no arguments, or giving it an undefined value)
        // Return all values as dict.
        if (key === undefined) {
            return this.values;
        }

        // Is key valid?
        // If not, create undefined entry
        if (key in this.values == false) {
            this.values[key] = undefined;
        }

        // If value not defined, returned specified value.
        if (newValue === undefined) {
            newValue = this.beforeGet(key);

            if (newValue !== undefined) {
                this.values[key] = newValue;
            }

            return this.values[key];
        }
        // If bot defined, store specified value.
        else {
            this.values[key] = newValue;
            newValue = this.afterSet(key, newValue);
        }
    }

    find(selector) {
        return this.getMenu().find(selector);
    }

    getMenu() {
        return jQuery("#tool-menu #" + this.menuId);
    }
}
